import { DisposableDelegate } from '@lumino/disposable';
import { ToolbarButton } from '@jupyterlab/apputils';
import { NotebookActions } from '@jupyterlab/notebook';
export class ButtonExtension {
    /**
     * Create a new extension for the notebook panel widget.
     *
     * @param panel Notebook panel
     * @param context Notebook context
     * @returns Disposable on the added button
     */
    createNew(panel, context) {
        const runAndReload = () => {
            NotebookActions.clearAllOutputs(panel.content);
        };
        const button = new ToolbarButton({
            className: 'run-and-reload',
            label: 'Run all cells and reload PDFs',
            onClick: runAndReload,
            tooltip: 'Run all cells and reload PDFs'
        });
        panel.toolbar.insertItem(10, 'runAndReload', button);
        return new DisposableDelegate(() => {
            button.dispose();
        });
    }
}
